==> aliyun-java-sdk-vod-2.15.2-sources.jar: com/aliyuncs/vod/transform/v20170321/DeleteTranscodeTemplateGroupResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vod.transform.v20170321;

import java.util.ArrayList;
import java.util.List;

import com.aliyuncs.vod.model.v20170321.DeleteTranscodeTemplateGroupResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class DeleteTranscodeTemplateGroupResponseUnmarshaller {

	public static DeleteTranscodeTemplateGroupResponse unmarshall(DeleteTranscodeTemplateGroupResponse deleteTranscodeTemplateGroupResponse, UnmarshallerContext context) {
		
		deleteTranscodeTemplateGroupResponse.setRequestId(context.stringValue("DeleteTranscodeTemplateGroupResponse.RequestId"));

		List<String> nonExistTranscodeTemplateIds = new ArrayList<String>();
		for (int i = 0; i < context.lengthValue("DeleteTranscodeTemplateGroupResponse.NonExistTranscodeTemplateIds.Length"); i++) {
			nonExistTranscodeTemplateIds.add(context.stringValue("DeleteTranscodeTemplateGroupResponse.NonExistTranscodeTemplateIds["+ i +"]"));
		}
		deleteTranscodeTemplateGroupResponse.setNonExistTranscodeTemplateIds(nonExistTranscodeTemplateIds);
	 
	 	return deleteTranscodeTemplateGroupResponse;
	}
}

==> aliyun-java-sdk-vod-2.15.8-sources.jar: com/aliyuncs/vod/transform/v20170321/DeleteTranscodeTemplateGroupResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vod.transform.v20170321;

import java.util.ArrayList;
import java.util.List;

import com.aliyuncs.vod.model.v20170321.DeleteTranscodeTemplateGroupResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class DeleteTranscodeTemplateGroupResponseUnmarshaller {

	public static DeleteTranscodeTemplateGroupResponse unmarshall(DeleteTranscodeTemplateGroupResponse deleteTranscodeTemplateGroupResponse, UnmarshallerContext _ctx) {
		
		deleteTranscodeTemplateGroupResponse.setRequestId(_ctx.stringValue("DeleteTranscodeTemplateGroupResponse.RequestId"));

		List<String> nonExistTranscodeTemplateIds = new ArrayList<String>();
		for (int i = 0; i < _ctx.lengthValue("DeleteTranscodeTemplateGroupResponse.NonExistTranscodeTemplateIds.Length"); i++) {
			nonExistTranscodeTemplateIds.add(_ctx.stringValue("DeleteTranscodeTemplateGroupResponse.NonExistTranscodeTemplateIds["+ i +"]"));
		}
		deleteTranscodeTemplateGroupResponse.setNonExistTranscodeTemplateIds(nonExistTranscodeTemplateIds);
	 
	 	return deleteTranscodeTemplateGroupResponse;
	}
}
